@@ -1,5 +1,5 @@
 package Perl::MinimumVersion;
-$Perl::MinimumVersion::VERSION = '1.39'; # TRIAL
+$Perl::MinimumVersion::VERSION = '1.41'; # TRIAL
 =pod
 
 =head1 NAME
@@ -23,7 +23,7 @@ version of perl required to be able to run it. Because it is based on
 L<PPI>, it can do this without having to actually load the code.
 
 Currently it tests both the syntax of your code, and the use of explicit
-version dependencies such as C<require 5.005>.
+version dependencies such as C<require 5.008>.
 
 Future plans are to also add support for tracing module dependencies.
 
@@ -66,6 +66,8 @@ BEGIN {
 
 	# The primary list of version checks
 	%CHECKS = (
+		_heredoc_indent         => version->new('5.025.007'),
+
         # _stacked_labels         => version->new('5.014'),
 
 		_yada_yada_yada         => version->new('5.012'),
@@ -78,50 +80,9 @@ BEGIN {
 		_perl_5010_operators    => version->new('5.010'),
 		_perl_5010_magic        => version->new('5.010'),
 		_state_declaration      => version->new('5.010'),
-
-		# Various small things
-		_bugfix_magic_errno     => version->new('5.008.003'),
-		_is_utf8                => version->new('5.008.001'),
-		_unquoted_versions      => version->new('5.008.001'),
-		_perl_5008_pragmas      => version->new('5.008'),
-		_constant_hash          => version->new('5.008'),
-		_local_soft_reference   => version->new('5.008'),
-		_use_carp_version       => version->new('5.008'),
-		_open_temp              => version->new('5.008'),
-		_open_scalar            => version->new('5.008'),
-		_internals_svreadonly   => version->new('5.008'),
-
-		# Included in 5.6. Broken until 5.8
-		_pragma_utf8            => version->new('5.008'),
-
-		_perl_5006_pragmas      => version->new('5.006'),
-		_any_our_variables      => version->new('5.006'),
-		_any_binary_literals    => version->new('5.006'),
-		_any_version_literals   => version->new('5.006'), #v-string
-		_magic_version          => version->new('5.006'),
-		_any_attributes         => version->new('5.006'),
-		_any_CHECK_blocks       => version->new('5.006'),
-		_three_argument_open    => version->new('5.006'),
-		_weaken                 => version->new('5.006'),
-		_mkdir_1_arg            => version->new('5.006'),
-		_exists_subr            => version->new('5.006'),
-		_sort_subref            => version->new('5.006'),
-
-		_any_qr_tokens          => version->new('5.005.03'),
-		_perl_5005_pragmas      => version->new('5.005'),
-		_perl_5005_modules      => version->new('5.005'),
-		_any_tied_arrays        => version->new('5.005'),
-		_any_quotelike_regexp   => version->new('5.005'),
-		_any_INIT_blocks        => version->new('5.005'),
-		_substr_4_arg           => version->new('5.005'),
-		_splice_negative_length => version->new('5.005'),
-		_5005_variables         => version->new('5.005'),
-		_bareword_double_colon  => version->new('5.005'),
-
-		_postfix_foreach        => version->new('5.004.05'),
 	);
 	@CHECKS_RV = ( #subs that return version
-	    '_feature_bundle','_regex','_each_argument','_binmode_2_arg',
+	    '_feature_bundle','_regex','_each_argument',,
         '_scheduled_blocks', '_experimental_bundle'
 	);
 
@@ -143,26 +104,6 @@ BEGIN {
 			'%+' => 1,
 			'%-' => 1,
 		},
-		_perl_5008_pragmas => {
-			threads           => 1,
-			'threads::shared' => 1,
-			sort              => 1,
-			encoding          => 1,
-		},
-		_perl_5006_pragmas => {
-			warnings             => 1, #may be ported into older version
-			'warnings::register' => 1,
-			attributes           => 1,
-			open                 => 1,
-			filetest             => 1,
-			charnames            => 1,
-			bytes                => 1,
-		},
-		_perl_5005_pragmas => {
-			re     => 1,
-			fields => 1, # can be installed from CPAN, with base.pm
-			attr   => 1,
-		},
 	);
 }
 
@@ -195,7 +136,7 @@ Returns a new C<Perl::MinimumVersion> object, or C<undef> on error.
 sub new {
 	my $class    = ref $_[0] ? ref shift : shift;
 	my $Document = _Document(shift) or return undef;
-	my $default  = _INSTANCE(shift, 'version') || version->new('5.004');
+	my $default  = _INSTANCE(shift, 'version') || version->new('5.008');
 
 	# Create the object
 	my $self = bless {
@@ -307,8 +248,8 @@ sub default_reason {
 The C<minimum_explicit_version> method checks through Perl code for the
 use of explicit version dependencies such as.
 
-  use 5.006;
-  require 5.005_03;
+  use 5.008;
+  require 5.010;
 
 Although there is almost always only one of these in a file, if more than
 one are found, the highest version dependency will be returned.
@@ -369,15 +310,15 @@ that this is possible.
 
 It takes an optional parameter of a L<version> object defining
 the lowest known current value. For example, if it is already known
-that it must be 5.006 or higher, then you can provide a param of
-qv(5.006) and the method will not run any of the tests below this
+that it must be 5.010 or higher, then you can provide a param of
+qv(5.010) and the method will not run any of the tests below this
 version. This should provide dramatic speed improvements for
 large and/or complex documents.
 
 The limitations of parsing Perl mean that this method may provide
 artificially low results, but should not artificially high results.
 
-For example, if C<minimum_syntax_version> returned 5.006, you can be
+For example, if C<minimum_syntax_version> returned 5.008, you can be
 confident it will not run on anything lower, although there is a chance
 that during actual execution it may use some untestable feature that
 creates a dependency on a higher version.
@@ -678,8 +619,6 @@ sub _experimental_bundle {
 
 my %SCHEDULED_BLOCK =
 (
-    'INIT'      => '5.006',
-    'CHECK'     => '5.006002',
     'UNITCHECK' => '5.010',
 );
 
@@ -706,20 +645,33 @@ sub _scheduled_blocks
 }
 
 sub _regex {
-    my @versions;
-    my ($version, $obj);
-	shift->Document->find( sub {
-	    return '' unless
+	my $self = shift;
+	my @versions;
+	my ($version, $obj);
+	$self->Document->find( sub {
+		return '' unless
 			grep { $_[1]->isa($_) }
 			qw/PPI::Token::QuoteLike::Regexp PPI::Token::Regexp::Match PPI::Token::Regexp::Substitute/;
 			my $re = PPIx::Regexp->new( $_[1] );
-        	my $v = $re->perl_version_introduced;
+			my $v = $re->perl_version_introduced;
 			if ($v and $v > ($version || 0) ) {
 				$version = $v;
 				$obj = $_[1];
 			}
 		return '';
 	} );
+	my $tr_r_version = version->new('5.013.007');
+	$self->Document->find( sub {
+		return '' unless
+			$_[1]->isa(q/PPI::Token::Regexp::Transliterate/);
+			if( exists $_[1]->get_modifiers->{r}
+				&& $tr_r_version > ( $version || 0 )
+			) {
+				$version = $tr_r_version;
+				$obj = $_[1];
+			}
+		return '';
+	} );
 	$version = undef if ($version and $version eq '5.000');
 	return ($version, $obj);
 }
@@ -774,42 +726,6 @@ sub _str_in_list {
 }
 
 
-sub _binmode_2_arg {
-    my ($version, $obj);
-	shift->Document->find_first( sub {
-		my $main_element=$_[1];
-		$main_element->isa('PPI::Token::Word') or return '';
-		$main_element->content eq 'binmode'       or return '';
-		return '' if is_hash_key($main_element);
-		return '' if is_method_call($main_element);
-		return '' if is_subroutine_name($main_element);
-		return '' if is_included_module_name($main_element);
-		return '' if is_package_declaration($main_element);
-		my @arguments = parse_arg_list($main_element);
-		if ( scalar @arguments == 2 ) {
-		    my $arg2=$arguments[1][0];
-			if ( $arg2->isa('PPI::Token::Quote')) { #check second argument
-				my $str = $arg2->string;
-				$str =~ s/^\s+//s;
-				$str =~ s/\s+$//s;
-				$str =~ s/:\s+/:/g;
-				if ( !_str_in_list( $str => qw/:raw :crlf/) and $str !~ /[\$\@\%]/) {
-            		$version = 5.008;
-		            $obj = $main_element;
-					return 1;
-				}
-			}
-			if (!$version) {
-        	    $version = 5.006;
-	            $obj = $main_element;
-	        }
-		}
-		return '';
-	} );
-	return ($version, $obj);
-}
-
-
 
 #http://perldoc.perl.org/functions/readdir.html
 #while(readdir $dh) requires perl 5.12
@@ -848,79 +764,6 @@ sub _perl_5012_pragmas {
 	} );
 }
 
-sub _sort_subref {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Token::Word') or return '';
-		$_[1]->content eq 'sort' or return '';
-		is_function_call($_[1]) or return '';
-		my $e1 = $_[1]->next_sibling;
-		$e1->isa('PPI::Token::Whitespace') or return '';
-		$e1 = $e1->next_sibling;
-		_get_resulting_sigil($e1) || '' eq '$' or return '';
-		$e1 = $e1->next_sibling;
-		$e1->isa('PPI::Token::Whitespace') or return '';
-		$e1 = $e1->next_sibling;
-		$e1->isa('PPI::Token::Word') or $e1->isa('PPI::Token::Symbol')
-			or $e1->isa('PPI::Token::Cast') or $e1->isa('PPI::Structure::List') or return '';
-		return 1;
-	} );
-}
-
-sub _open_temp {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement') or return '';
-		my @children = $_[1]->children;
-		#@children >= 7                or return '';
-		my $main_element = $children[0];
-		$main_element->isa('PPI::Token::Word') or return '';
-		$main_element->content eq 'open'       or return '';
-		my @arguments = parse_arg_list($main_element);
-		if ( scalar @arguments == 3 and scalar(@{$arguments[2]}) == 1) {
-		    my $arg3 = $arguments[2][0];
-		    if ($arg3->isa('PPI::Token::Word') and $arg3->content eq 'undef') {
-				return 1;
-			}
-		}
-		return '';
-	} );
-}
-
-sub _open_scalar {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement') or return '';
-		my @children = $_[1]->children;
-		#@children >= 7                or return '';
-		my $main_element = $children[0];
-		$main_element->isa('PPI::Token::Word') or return '';
-		$main_element->content eq 'open'       or return '';
-		my @arguments = parse_arg_list($main_element);
-		if ( scalar @arguments == 3) {
-		    my $arg3 = $arguments[2][0];
-		    if ($arg3->isa('PPI::Token::Cast') and $arg3->content eq '\\') {
-				return 1;
-			}
-		}
-		return '';
-	} );
-}
-
-# exists(&subr) new in 5.6.0 #
-sub _exists_subr {
-	my ($pmv) = @_;
-	$pmv->Document->find_first(sub {
-		my ($document, $elem) = @_;
-		if ($elem->isa('PPI::Token::Word')
-			&& $elem eq 'exists'
-			&& is_function_call($elem)
-			&& ($elem = first_arg($elem))
-			&& (_get_resulting_sigil($elem) || '') eq '&') {
-				return 1;
-		} else {
-			return 0;
-		}
-	});
-}
-
 sub _get_resulting_sigil {
 	my $elem = shift;
 	if ($elem->isa('PPI::Token::Cast')) {
@@ -932,6 +775,14 @@ sub _get_resulting_sigil {
 	}
 }
 
+sub _heredoc_indent {
+	shift->Document->find_first( sub {
+		my $main_element = $_[1];
+		$main_element->isa('PPI::Token::HereDoc') or return '';
+		$main_element->content =~ /^\Q<<~\E/ or return '';
+		return 1;
+	});
+}
 
 sub _postfix_when {
 	shift->Document->find_first( sub {
@@ -986,14 +837,6 @@ sub _stacked_labels {
     } );
 }
 
-sub _internals_svreadonly {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement')
-        and ($_[1]->children)[0]->isa('PPI::Token::Word')
-        and ($_[1]->children)[0]->content eq 'Internals::SvREADONLY'
-	} );
-}
-
 sub _pkg_name_version {
 	shift->Document->find_first( sub {
 		$_[1]->isa('PPI::Statement::Package') or return '';
@@ -1030,379 +873,6 @@ sub _perl_5010_magic {
 	} );
 }
 
-sub _perl_5008_pragmas {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement::Include')
-		and
-		$MATCHES{_perl_5008_pragmas}->{$_[1]->pragma}
-	} );
-}
-
-# 5.8.3: Reading $^E now preserves $!. Previously, the C code implementing $^E did not preserve errno, so reading $^E could cause errno and therefore $! to change unexpectedly.
-sub _bugfix_magic_errno {
-	my $Document = shift->Document;
-	my $element = $Document->find_first( sub {
-		$_[1]->isa('PPI::Token::Magic')
-		and
-		$_[1]->symbol eq '$^E'
-	} ) || return undef;
-	#$^E is more rare than $!, so search for it first and return it
-	$Document->find_any( sub {
-		$_[1]->isa('PPI::Token::Magic')
-		and
-		$_[1]->symbol eq '$!'
-	} ) || return '';
-	return $element;
-}
-
-# utf8::is_utf requires 5.8.1 unlike the rest of utf8
-sub _is_utf8 {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Token::Word') or return '';
-		$_[1] eq 'utf8::is_utf'        or return '';
-		return 1;
-	} );
-}
-
-# version->new(5.005.004);
-sub _unquoted_versions {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Token::Number')       or return '';
-		$_[1]->{_subtype}                      or return '';
-		$_[1]->{_subtype} eq 'base256'         or return '';
-		my $stmt   = $_[1]->parent             or return '';
-		my $braces = $stmt->parent             or return '';
-		$braces->isa('PPI::Structure')         or return '';
-		$braces->braces eq '()'                or return '';
-		my $new = $braces->previous_sibling    or return '';
-		$new->isa('PPI::Token::Word')          or return '';
-		$new->content eq 'new'                 or return '';
-		my $method = $new->previous_sibling    or return '';
-		$method->isa('PPI::Token::Operator')   or return '';
-		$method->content eq '->'               or return '';
-		my $_class = $method->previous_sibling or return '';
-		$_class->isa('PPI::Token::Word')       or return '';
-		$_class->content eq 'version'          or return '';
-		1;
-	} );
-}
-
-sub _pragma_utf8 {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement::Include')
-		and
-		(
-			($_[1]->module and $_[1]->module eq 'utf8')
-			or
-			($_[1]->pragma and $_[1]->pragma eq 'utf8')
-		)
-		# This used to be just pragma(), but that was buggy in PPI v1.118
-	} );
-}
-
-# Check for the use of 'use constant { ... }'
-sub _constant_hash {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement::Include')
-		and
-		$_[1]->type
-		and
-		$_[1]->type eq 'use'
-		and
-		$_[1]->module eq 'constant'
-		and
-		$_[1]->schild(2)->isa('PPI::Structure')
-	} );
-}
-
-sub _perl_5006_pragmas {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement::Include')
-		and
-		$MATCHES{_perl_5006_pragmas}->{$_[1]->pragma}
-	} );
-}
-
-sub _any_our_variables {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement::Variable')
-		and
-		$_[1]->type eq 'our'
-	} );
-}
-
-sub _any_binary_literals {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Token::Number::Binary')
-	} );
-}
-
-sub _any_version_literals {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Token::Number::Version')
-	} );
-}
-
-
-sub _magic_version {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Token::Magic')
-		and
-		$_[1]->symbol eq '$^V'
-	} );
-}
-
-sub _any_attributes {
-	shift->Document->find_first( 'Token::Attribute' );
-}
-
-sub _any_CHECK_blocks {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement::Scheduled')
-		and
-		$_[1]->type eq 'CHECK'
-	} );
-}
-
-sub _any_qr_tokens {
-	shift->Document->find_first( 'Token::QuoteLike::Regexp' );
-}
-
-sub _perl_5005_pragmas {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement::Include')
-		and
-		$MATCHES{_perl_5005_pragmas}->{$_[1]->pragma}
-	} );
-}
-
-# A number of modules are highly indicative of using techniques
-# that are themselves version-dependent.
-sub _perl_5005_modules {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement::Include')
-		and
-		$_[1]->module
-		and (
-			$_[1]->module eq 'Tie::Array'
-			or
-			($_[1]->module =~ /\bException\b/ and
-				$_[1]->module !~ /^(?:CPAN)::/)
-			or
-			$_[1]->module =~ /\bThread\b/
-			or
-			$_[1]->module =~ /^Error\b/
-			or
-			$_[1]->module eq 'base'
-			or
-			$_[1]->module eq 'Errno'
-		)
-	} );
-}
-
-sub _any_tied_arrays {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement::Sub')
-		and
-		$_[1]->name eq 'TIEARRAY'
-	} )
-}
-
-sub _any_quotelike_regexp {
-	shift->Document->find_first( 'Token::QuoteLike::Regexp' );
-}
-
-sub _any_INIT_blocks {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement::Scheduled')
-		and
-		$_[1]->type eq 'INIT'
-	} );
-}
-
-# You can't localize a soft reference
-sub _local_soft_reference {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement::Variable')  or return '';
-		$_[1]->type eq 'local'                  or return '';
-
-		# The second child should be a '$' cast.
-		my @child = $_[1]->schildren;
-		scalar(@child) >= 2                     or return '';
-		$child[1]->isa('PPI::Token::Cast')      or return '';
-		$child[1]->content eq '$'               or return '';
-
-		# The third child should be a block
-		$child[2]->isa('PPI::Structure::Block') or return '';
-
-		# Inside the block should be a string in a statement
-		my $statement = $child[2]->schild(0)    or return '';
-		$statement->isa('PPI::Statement')       or return '';
-		my $inside = $statement->schild(0)      or return '';
-		$inside->isa('PPI::Token::Quote')       or return '';
-
-		# This is indeed a localized soft reference
-		return 1;
-	} );
-}
-
-# Carp.pm did not have a $VERSION in 5.6.2
-# Therefore, even "use Carp 0" imposes a 5.8.0 dependency.
-sub _use_carp_version {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement::Include') or return '';
-		$_[1]->module eq 'Carp'               or return '';
-
-		my $version = $_[1]->module_version;
-		return !! ( defined $version and length "$version" );
-	} );
-}
-
-sub _three_argument_open {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Statement') or return '';
-		my @children = $_[1]->children;
-		#@children >= 7                or return '';
-		my $main_element = $children[0];
-		$main_element->isa('PPI::Token::Word') or return '';
-		$main_element->content eq 'open'       or return '';
-		my @arguments = parse_arg_list($main_element);
-		if ( scalar @arguments > 2 ) {
-			return 1;
-		}
-		return '';
-	} );
-}
-
-sub _substr_4_arg {
-	shift->Document->find_first( sub {
-		my $main_element=$_[1];
-		$main_element->isa('PPI::Token::Word') or return '';
-		$main_element->content eq 'substr'     or return '';
-		return '' if is_hash_key($main_element);
-		return '' if is_method_call($main_element);
-		return '' if is_subroutine_name($main_element);
-		return '' if is_included_module_name($main_element);
-		return '' if is_package_declaration($main_element);
-		my @arguments = parse_arg_list($main_element);
-		if ( scalar @arguments > 3 ) {
-			return 1;
-		}
-		return '';
-	} );
-}
-
-sub _mkdir_1_arg {
-	shift->Document->find_first( sub {
-		my $main_element=$_[1];
-		$main_element->isa('PPI::Token::Word') or return '';
-		$main_element->content eq 'mkdir'       or return '';
-		return '' if is_hash_key($main_element);
-		return '' if is_method_call($main_element);
-		return '' if is_subroutine_name($main_element);
-		return '' if is_included_module_name($main_element);
-		return '' if is_package_declaration($main_element);
-		my @arguments = parse_arg_list($main_element);
-		if ( scalar @arguments != 2 ) {
-			return 1;
-		}
-		return '';
-	} );
-}
-
-sub _splice_negative_length {
-	shift->Document->find_first( sub {
-		my $main_element=$_[1];
-		$main_element->isa('PPI::Token::Word') or return '';
-		$main_element->content eq 'splice'     or return '';
-		return '' if is_hash_key($main_element);
-		return '' if is_method_call($main_element);
-		return '' if is_subroutine_name($main_element);
-		return '' if is_included_module_name($main_element);
-		return '' if is_package_declaration($main_element);
-
-		my @arguments = parse_arg_list($main_element);
-		if ( scalar @arguments < 3 ) {
-			return '';
-		}
-		my $arg=$arguments[2];
-		if (ref($arg) eq 'ARRAY') {
-		  $arg=$arg->[0];
-		}
-		if ($arg->isa('PPI::Token::Number')) {
-			if ($arg->literal<0) {
-				return 1;
-			} else {
-				return '';
-			}
-		}
-		return '';
-	} );
-
-}
-
-sub _postfix_foreach {
-	shift->Document->find_first( sub {
-		my $main_element=$_[1];
-		$main_element->isa('PPI::Token::Word') or return '';
-		$main_element->content eq 'foreach'    or return '';
-		return '' if is_hash_key($main_element);
-		return '' if is_method_call($main_element);
-		return '' if is_subroutine_name($main_element);
-		return '' if is_included_module_name($main_element);
-		return '' if is_package_declaration($main_element);
-		my $stmnt = $main_element->statement();
-		return '' if !$stmnt;
-		return '' if $stmnt->isa('PPI::Statement::Compound');
-		return 1;
-	} );
-}
-
-# weak references require perl 5.6
-# will not work in case of importing several
-sub _weaken {
-	shift->Document->find_first( sub {
-		(
-			$_[1]->isa('PPI::Statement::Include')
-			and
-			$_[1]->module eq 'Scalar::Util'
-			and
-			$_[1]->content =~ /[^:]\b(?:weaken|isweak)\b[^:]/
-		)
-		or
-		(
-			$_[1]->isa('PPI::Token::Word')
-			and
-			(
-				$_[1]->content eq 'Scalar::Util::isweak'
-				or
-				$_[1]->content eq 'Scalar::Util::weaken'
-			)
-			#and
-			#is_function_call($_[1])
-		)
-	} );
-}
-
-sub _5005_variables {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Token::Magic')
-		and
-		($_[1]->symbol eq '$!' or $_[1]->symbol eq '$^R')
-	} );
-}
-
-#added in 5.5
-sub _bareword_double_colon {
-	shift->Document->find_first( sub {
-		$_[1]->isa('PPI::Token::Word')
-		and
-		$_[1]->content =~ /::$/
-	} );
-}
-
-
-
 #####################################################################
 # Support Functions
 
